@@ -68,7 +68,7 @@
 #include <libmapi/libmapi.h>
 #include <param.h>
 
-#define d(x) printf("%s(%d):%s:%s \n", __FILE__, __LINE__, __PRETTY_FUNCTION__, x)
+#define d(x) printf("%s:%s:%s \n", G_STRLOC, G_STRFUNC, x)
 
 struct _CamelMapiStorePrivate {
 	char *user;
@@ -261,6 +261,8 @@ static char
 	if (brief) {
 		return g_strdup_printf(_("Exchange MAPI server %s"), service->url->host);
 	} else {
+		/*To translators : Example string : Exchange MAPI service for 
+		  _username_ on _server host name__*/
 		return g_strdup_printf(_("Exchange MAPI service for %s on %s"),
 				       service->url->user, service->url->host);
 	}
@@ -295,8 +297,11 @@ mapi_auth_loop (CamelService *service, CamelException *ex)
 		if (!service->url->passwd ){
 			char *prompt;
 			
-			prompt = g_strdup_printf (_("%sPlease enter the MAPI "
-						    "password for %s@%s"),
+			/*To translators : First %s : is the error text or the reason
+			  for prompting the user if it is available.
+			 Second %s is : Username.
+			 Third %s is : Server host name.*/
+			prompt = g_strdup_printf (_("%s Please enter the MAPI password for %s@%s"),
 						  errbuf ? errbuf : "",
 						  service->url->user,
 						  service->url->host);
@@ -370,7 +375,6 @@ static gboolean
 mapi_disconnect(CamelService *service, gboolean clean, CamelException *ex)
 {
 	CamelMapiStore *store = CAMEL_MAPI_STORE (service);
-	CamelMapiStorePrivate *priv = store->priv;
 
 	/* Close the mapi subsystem */
 	exchange_mapi_connection_close ();
@@ -467,9 +471,9 @@ mapi_create_folder(CamelStore *store, const char *parent_name, const char *folde
 		si = camel_mapi_store_summary_add_from_full(mapi_store->summary, root->full_name, '/');
 		camel_store_summary_save((CamelStoreSummary *)mapi_store->summary);
 
-		g_hash_table_insert (priv->id_hash, g_strdup_printf ("%016llX", new_folder_id), g_strdup(folder_name));
-		g_hash_table_insert (priv->name_hash, g_strdup(root->full_name), g_strdup_printf ("%016llX", new_folder_id));
-		g_hash_table_insert (priv->parent_hash, g_strdup_printf ("%016llX", new_folder_id), g_strdup(parent_id));
+		g_hash_table_insert (priv->id_hash, g_strdup_printf ("%016" G_GINT64_MODIFIER "X", new_folder_id), g_strdup(folder_name));
+		g_hash_table_insert (priv->name_hash, g_strdup(root->full_name), g_strdup_printf ("%016" G_GINT64_MODIFIER "X", new_folder_id));
+		g_hash_table_insert (priv->parent_hash, g_strdup_printf ("%016" G_GINT64_MODIFIER "X", new_folder_id), g_strdup(parent_id));
 
 		camel_object_trigger_event (CAMEL_OBJECT (store), "folder_created", root);
 	}
@@ -482,9 +486,8 @@ mapi_create_folder(CamelStore *store, const char *parent_name, const char *folde
 static void
 mapi_forget_folder (CamelMapiStore *mapi_store, const char *folder_name, CamelException *ex)
 {
-	CamelFolderSummary *summary;
 	CamelMapiStorePrivate *priv = mapi_store->priv;
-	char *summary_file, *state_file;
+	char *state_file;
 	char *folder_dir, *storage_path;
 	CamelFolderInfo *fi;
 	const char *name;
@@ -494,7 +497,8 @@ mapi_forget_folder (CamelMapiStore *mapi_store, const char *folder_name, CamelEx
 	storage_path = g_strdup_printf ("%s/folders", priv->storage_path);
 
 	/* Fixme Path - e_*-to_path */
-	folder_dir = g_strdup(g_strconcat (storage_path, "/", folder_name, NULL));
+	folder_dir = g_strconcat (storage_path, "/", folder_name, NULL);
+	g_free (storage_path);
 
 	if (g_access(folder_dir, F_OK) != 0) {
 		g_free(folder_dir);
@@ -648,6 +652,7 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	folder_id = camel_mapi_store_folder_id_lookup (mapi_store, temp);
 	if (!folder_id) {
+		/*To translators : '%s' is current name of the folder */
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
 				      _("Cannot rename MAPI folder `%s'. Folder does not exist."),
 				      old_name);
@@ -657,8 +662,10 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 
 	/*Do not allow rename for system folders.*/
 	if (mapi_fid_is_system_folder (mapi_store, folder_id)) {
+		/*To translators : '%s to %s' is current name of the folder  and
+		 new name of the folder.*/
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
-				      _("Cannot rename MAPI folder `%s' to `%s'. Default folder."),
+				      _("Cannot rename MAPI default folder `%s' to `%s'."),
 				      old_name, new_name);
 		return;
 	}
@@ -673,6 +680,8 @@ mapi_rename_folder(CamelStore *store, const char *old_name, const char *new_name
 	
 	if (!exchange_mapi_rename_folder (fid , temp))
 	{
+		/*To translators : '%s to %s' is current name of the folder  and
+		 new name of the folder.*/
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, 
 				      _("Cannot rename MAPI folder `%s' to `%s'"), old_name, new_name);
 
@@ -727,7 +736,7 @@ static guint32 hexnib(guint32 c)
 char *
 camel_mapi_store_summary_path_to_full(CamelMapiStoreSummary *s, const char *path, char dir_sep)
 {
-	unsigned char *full, *f;
+	char *full, *f;
 	guint32 c, v = 0;
 	const char *p;
 	int state=0;
@@ -767,7 +776,7 @@ camel_mapi_store_summary_path_to_full(CamelMapiStoreSummary *s, const char *path
 				else {
 					if (c == '/')
 						c = dir_sep;
-					camel_utf8_putc(&f, c);
+					camel_utf8_putc((unsigned char **)&f, c);
 				}
 				break;
 			case 1:
@@ -777,11 +786,11 @@ camel_mapi_store_summary_path_to_full(CamelMapiStoreSummary *s, const char *path
 			case 2:
 				state = 0;
 				v |= hexnib(c);
-				camel_utf8_putc(&f, v);
+				camel_utf8_putc((unsigned char **)&f, v);
 				break;
 		}
 	}
-	camel_utf8_putc(&f, c);
+	camel_utf8_putc((unsigned char **)&f, c);
 
 	/* merge old path part if required */
 	f = g_strdup (full);
@@ -985,7 +994,7 @@ mapi_convert_to_folder_info (CamelMapiStore *store, ExchangeMAPIFolder *folder,
 
 	name = exchange_mapi_folder_get_name (folder);
 
-	id = g_strdup_printf ("%016llX", exchange_mapi_folder_get_fid (folder));
+	id = g_strdup_printf ("%016" G_GINT64_MODIFIER "X", exchange_mapi_folder_get_fid (folder));
 		
 	fi = g_new0 (CamelFolderInfo, 1);
 
@@ -1003,7 +1012,12 @@ mapi_convert_to_folder_info (CamelMapiStore *store, ExchangeMAPIFolder *folder,
 		case olFolderDeletedItems:
 			fi->flags |= CAMEL_FOLDER_TYPE_TRASH;
 			break;
-		/*TODO : case olFolderJunkMail */
+		case olFolderOutbox:
+			fi->flags |= CAMEL_FOLDER_TYPE_OUTBOX;
+			break;
+		case olFolderJunk:
+			fi->flags |= CAMEL_FOLDER_TYPE_JUNK;
+			break;
 		}
 
 		fi->flags |= CAMEL_FOLDER_SYSTEM;
@@ -1024,7 +1038,7 @@ mapi_convert_to_folder_info (CamelMapiStore *store, ExchangeMAPIFolder *folder,
 	 */
 
 	mapi_id_folder = exchange_mapi_folder_get_parent_id (folder);
-	parent = g_strdup_printf ("%016llX", mapi_id_folder);
+	parent = g_strdup_printf ("%016" G_GINT64_MODIFIER "X", mapi_id_folder);
 	par_name = g_hash_table_lookup (priv->id_hash, parent);
 
 	if (par_name != NULL) {
@@ -1130,8 +1144,8 @@ mapi_folders_sync (CamelMapiStore *store, CamelException *ex)
 		gchar *fid = NULL, *parent_id = NULL;
 
 		name = exchange_mapi_folder_get_name ((ExchangeMAPIFolder *)(temp_list->data));
-		fid = g_strdup_printf ("%016llX", exchange_mapi_folder_get_fid((ExchangeMAPIFolder *)(temp_list->data)));
-		parent_id = g_strdup_printf ("%016llX", exchange_mapi_folder_get_parent_id ((ExchangeMAPIFolder *)(temp_list->data)));
+		fid = g_strdup_printf ("%016" G_GINT64_MODIFIER "X", exchange_mapi_folder_get_fid((ExchangeMAPIFolder *)(temp_list->data)));
+		parent_id = g_strdup_printf ("%016" G_GINT64_MODIFIER "X", exchange_mapi_folder_get_parent_id ((ExchangeMAPIFolder *)(temp_list->data)));
 
 		/*id_hash returns the name for a given container id*/
 		g_hash_table_insert (priv->id_hash, g_strdup (fid), g_strdup(name)); 
@@ -1153,7 +1167,7 @@ mapi_folders_sync (CamelMapiStore *store, CamelException *ex)
 	for (;folder_list != NULL; folder_list = g_slist_next (folder_list)) {
 		ExchangeMAPIFolder *folder = (ExchangeMAPIFolder *) folder_list->data;
 		
-		if (exchange_mapi_folder_is_root ((ExchangeMAPIFolder *)(folder)))
+		if (folder->default_type == olPublicFoldersAllPublicFolders)
 			continue;
 
 		if ( folder->container_class != MAPI_FOLDER_TYPE_MAIL) 
@@ -1212,7 +1226,7 @@ mapi_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelExc
 	} 
 
 	/*camel_exception_clear (ex);*/
-end_r:
+
 	s_count = camel_store_summary_count((CamelStoreSummary *)mapi_store->summary);
 	info = mapi_get_folder_info_offline (store, top, flags, ex);
 	return info;
